"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.TEXT = void 0;

var _react = _interopRequireDefault(require("react"));

var _eui = require("@elastic/eui");

var _constants = require("../../../../utils/constants");

/*
 * Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
var TEXT = {
  RESET_FILTERS: "There are no policies matching your applied filters. Reset your filters to view your policies.",
  NO_POLICIES: "There are no existing policies. Create a policy to apply to your indices.",
  LOADING: "Loading policies..."
};
exports.TEXT = TEXT;

var getMessagePrompt = function getMessagePrompt(_ref) {
  var filterIsApplied = _ref.filterIsApplied,
      loading = _ref.loading;
  if (loading) return TEXT.LOADING;
  if (filterIsApplied) return TEXT.RESET_FILTERS;
  return TEXT.NO_POLICIES;
};

var getActions = function getActions(_ref2) {
  var filterIsApplied = _ref2.filterIsApplied,
      loading = _ref2.loading,
      resetFilters = _ref2.resetFilters;

  if (loading) {
    return null;
  }

  if (filterIsApplied) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      fill: true,
      onClick: resetFilters,
      "data-test-subj": "policyEmptyPromptRestFilters"
    }, "Reset Filters");
  }

  return /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    fill: true,
    href: "".concat(_constants.PLUGIN_NAME, "#").concat(_constants.ROUTES.CREATE_POLICY)
  }, "Create policy");
};

var PolicyEmptyPrompt = function PolicyEmptyPrompt(props) {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
    style: {
      maxWidth: "45em"
    },
    body: /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, getMessagePrompt(props))),
    actions: getActions(props)
  });
};

var _default = PolicyEmptyPrompt;
exports.default = _default;