"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _test = require("../../test");

var _global_toast_list = require("./global_toast_list");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('EuiGlobalToastList', function () {
  test('is rendered', function () {
    var component = (0, _enzyme.render)(_react.default.createElement(_global_toast_list.EuiGlobalToastList, _extends({}, _test.requiredProps, {
      dismissToast: function dismissToast() {},
      toastLifeTimeMs: 5
    })));
    expect(component).toMatchSnapshot();
  });
  describe('props', function () {
    describe('toasts', function () {
      test('is rendered', function () {
        var toasts = [{
          title: 'A',
          text: 'a',
          color: 'success',
          iconType: 'check',
          'data-test-subj': 'a',
          id: 'a'
        }, {
          title: 'B',
          text: 'b',
          color: 'danger',
          iconType: 'alert',
          'data-test-subj': 'b',
          id: 'b'
        }];
        var component = (0, _enzyme.render)(_react.default.createElement(_global_toast_list.EuiGlobalToastList, {
          toasts: toasts,
          dismissToast: function dismissToast() {},
          toastLifeTimeMs: 5
        }));
        expect(component).toMatchSnapshot();
      });
    });
    describe('dismissToast', function () {
      test('is called when a toast is clicked', function (done) {
        var dismissToastSpy = jest.fn();
        var component = (0, _enzyme.mount)(_react.default.createElement(_global_toast_list.EuiGlobalToastList, {
          toasts: [{
            'data-test-subj': 'b',
            id: 'b'
          }],
          dismissToast: dismissToastSpy,
          toastLifeTimeMs: 100
        }));
        var toastB = (0, _test.findTestSubject)(component, 'b');
        var closeButton = (0, _test.findTestSubject)(toastB, 'toastCloseButton');
        closeButton.simulate('click'); // The callback is invoked once the toast fades from view.

        setTimeout(function () {
          expect(dismissToastSpy).toBeCalled();
          done();
        }, _global_toast_list.TOAST_FADE_OUT_MS + 1);
      });
      test('is called when the toast lifetime elapses', function (done) {
        var TOAST_LIFE_TIME_MS = 5;
        var dismissToastSpy = jest.fn();
        (0, _enzyme.mount)(_react.default.createElement(_global_toast_list.EuiGlobalToastList, {
          toasts: [{
            'data-test-subj': 'b',
            id: 'b'
          }],
          dismissToast: dismissToastSpy,
          toastLifeTimeMs: TOAST_LIFE_TIME_MS
        })); // The callback is invoked once the toast fades from view.

        setTimeout(function () {
          expect(dismissToastSpy).toBeCalled();
          done();
        }, TOAST_LIFE_TIME_MS + _global_toast_list.TOAST_FADE_OUT_MS + 10);
      });
      test('toastLifeTimeMs is overrideable by individidual toasts', function (done) {
        var TOAST_LIFE_TIME_MS = 10;
        var TOAST_LIFE_TIME_MS_OVERRIDE = 100;
        var dismissToastSpy = jest.fn();
        (0, _enzyme.mount)(_react.default.createElement(_global_toast_list.EuiGlobalToastList, {
          toasts: [{
            'data-test-subj': 'b',
            id: 'b',
            toastLifeTimeMs: TOAST_LIFE_TIME_MS_OVERRIDE
          }],
          dismissToast: dismissToastSpy,
          toastLifeTimeMs: TOAST_LIFE_TIME_MS
        })); // The callback is invoked once the toast fades from view.

        setTimeout(function () {
          expect(dismissToastSpy).not.toBeCalled();
        }, TOAST_LIFE_TIME_MS + _global_toast_list.TOAST_FADE_OUT_MS + 10);
        setTimeout(function () {
          expect(dismissToastSpy).toBeCalled();
          done();
        }, TOAST_LIFE_TIME_MS_OVERRIDE + _global_toast_list.TOAST_FADE_OUT_MS + 10);
      });
    });
  });
});